# Wigglegram Camera

Welcome to your brand-new open-source wigglecam! Turn stereoscopic images into a wigglegram.

[![PyPI](https://img.shields.io/pypi/v/wigglecam)](https://pypi.org/project/wigglecam/)
[![ruff](https://github.com/photobooth-app/wigglecam/actions/workflows/ruff.yml/badge.svg)](https://github.com/photobooth-app/wigglecam/actions/workflows/ruff.yml)
[![pytest](https://github.com/photobooth-app/wigglecam/actions/workflows/pytests.yml/badge.svg)](https://github.com/photobooth-app/wigglecam/actions/workflows/pytests.yml)
[![codecov](https://codecov.io/gh/photobooth-app/wigglecam/graph/badge.svg?token=87aLWw2gIT)](https://codecov.io/gh/photobooth-app/wigglecam)

![demo wigglegram](https://raw.githubusercontent.com/photobooth-app/wigglecam/main/assets/wigglegram-demo1.gif)

![DIY wigglegram camera 3d printed](https://raw.githubusercontent.com/photobooth-app/wigglecam/main/assets/cam1.jpg)

🧪 This is experimental 🧪

## 😍 What it is

🧪 Python software to capture wigglegrams using multiple cameras  
🧪 Software synchronized Raspberry Pi camera modules, using picamera2  
🧪 3d printed enclosure  
🧪 Creating smooth videos from just two images using frame interpolation AI algorithms  

## Hardware

![wiring diagram overview](https://raw.githubusercontent.com/photobooth-app/wigglecam/main/assets/wiringdiagram.png)

## More Info

[Find more information in the documentation.](https://photobooth-app.org/wigglegramcamera/)
